# Welcome
This is the current release of baangt - the tool for "Basic And Advanced Next Generation Testing".

## Installation in a virtual environment:
``pip install baangt``

#Usage:


#Further reading:
Please see latest news on http://baangt.org for community edition and http://baangt.com for corporate environments